@@ -130,7 +130,6 @@ mod palette;
 mod pixel;
 mod plane;
 mod resizecb;
-mod signal;
 mod stats;
 mod time;
 mod visual;
@@ -153,7 +152,6 @@ pub use pixel::*;
 pub use plane::*;
 pub use r#box::*;
 pub use resizecb::*;
-pub use signal::*;
 pub use stats::*;
 pub use time::*;
 pub use visual::*;
