@@ -4,9 +4,8 @@ use core::ptr::{null, null_mut};
 
 use crate::{
     cstring, error, error_ref_mut, notcurses_init, rstring, Nc, NcAlign, NcBlitter, NcChannels,
-    NcDim, NcEgc, NcError, NcFile, NcInput, NcLogLevel, NcOptions, NcPlane, NcResult, NcScale,
-    NcSignalSet, NcStats, NcStyle, NcTime, NCOPTION_NO_ALTERNATE_SCREEN, NCOPTION_SUPPRESS_BANNERS,
-    NCRESULT_ERR,
+    NcDim, NcError, NcFile, NcInput, NcLogLevel, NcOptions, NcPlane, NcResult, NcScale, NcStats,
+    NcStyle, NcTime, NCOPTION_NO_ALTERNATE_SCREEN, NCOPTION_SUPPRESS_BANNERS, NCRESULT_ERR,
 };
 
 /// # `NcOptions` Constructors
@@ -130,10 +129,11 @@ impl Nc {
     }
 
     /// Retrieves the current contents of the specified [NcCell][crate::NcCell]
-    /// as last rendered, returning the [NcEgc] (or None on error) and writing
-    /// out the [NcStyle] and the [NcChannels].
+    /// as last rendered, returning the `EGC` (or None on error) and writing
+    /// out the [`NcStyle`] and the [`NcChannels`].
     ///
-    /// This NcEgc must be freed by the caller.
+    // possible BUG? CHECK:
+    /// This `EGC` must be freed by the caller.
     ///
     /// *C style function: [notcurses_at_yx()][crate::notcurses_at_yx].*
     pub fn at_yx(
@@ -142,16 +142,15 @@ impl Nc {
         x: NcDim,
         stylemask: &mut NcStyle,
         channels: &mut NcChannels,
-    ) -> Option<NcEgc> {
+    ) -> Option<String> {
         let egc = unsafe { crate::notcurses_at_yx(self, x as i32, y as i32, stylemask, channels) };
         if egc.is_null() {
             return None;
         }
-        let egc = core::char::from_u32(unsafe { *egc } as u32).expect("wrong char");
-        Some(egc)
+        Some(rstring![egc].into())
     }
 
-    /// Returns the bottommost [NcPlane] on the standard pile,
+    /// Returns the bottommost [`NcPlane`] on the standard pile,
     /// of which there is always at least one.
     ///
     /// *C style function: [notcurses_bottom()][crate::notcurses_bottom].*
@@ -306,7 +305,7 @@ impl Nc {
         rstring![crate::notcurses_detected_terminal(self)].to_string()
     }
 
-    /// Destroys all [NcPlane]s other than the stdplane.
+    /// Destroys all [`NcPlane`]s other than the stdplane.
     ///
     /// *C style function: [notcurses_drop_planes()][crate::notcurses_drop_planes].*
     pub fn drop_planes(&mut self) {
@@ -323,18 +322,8 @@ impl Nc {
     /// Provide a None `time` to block at length, a `time` of 0 for non-blocking
     /// operation, and otherwise a timespec to bound blocking.
     ///
-    /// Signals in sigmask (less several we handle internally) will be atomically
-    /// masked and unmasked per [ppoll(2)](https://linux.die.net/man/2/ppoll).
-    ///
-    /// `*sigmask` should generally contain all signals.
-    ///
     /// *C style function: [notcurses_getc()][crate::notcurses_getc].*
-    pub fn getc(
-        &mut self,
-        time: Option<NcTime>,
-        sigmask: Option<&mut NcSignalSet>,
-        input: Option<&mut NcInput>,
-    ) -> NcResult<char> {
+    pub fn getc(&mut self, time: Option<NcTime>, input: Option<&mut NcInput>) -> NcResult<char> {
         let ntime;
         if let Some(time) = time {
             ntime = &time as *const _;
@@ -342,12 +331,6 @@ impl Nc {
             ntime = null();
         }
 
-        let nsigmask;
-        if let Some(sigmask) = sigmask {
-            nsigmask = sigmask as *mut _;
-        } else {
-            nsigmask = null_mut() as *mut _;
-        }
         let ninput;
         if let Some(input) = input {
             ninput = input as *mut _;
@@ -355,7 +338,7 @@ impl Nc {
             ninput = null_mut();
         }
         let c = unsafe {
-            core::char::from_u32_unchecked(crate::notcurses_getc(self, ntime, nsigmask, ninput))
+            core::char::from_u32_unchecked(crate::notcurses_getc(self, ntime, null_mut(), ninput))
         };
         if c as u32 as i32 == NCRESULT_ERR {
             return Err(NcError::new());
@@ -409,7 +392,7 @@ impl Nc {
         error![unsafe { crate::notcurses_inputready_fd(self) }]
     }
 
-    /// Returns an [NcBlitter] from a string representation.
+    /// Returns an [`NcBlitter`] from a string representation.
     ///
     /// *C style function: [notcurses_lex_blitter()][crate::notcurses_lex_blitter].*
     pub fn lex_blitter(op: &str) -> NcResult<NcBlitter> {
@@ -430,7 +413,7 @@ impl Nc {
         error![unsafe { crate::notcurses_lex_margins(cstring![op], options) }]
     }
 
-    /// Returns an [NcScale] from a string representation.
+    /// Returns an [`NcScale`] from a string representation.
     ///
     /// *C style function: [notcurses_lex_scalemode()][crate::notcurses_lex_scalemode].*
     pub fn lex_scalemode(op: &str) -> NcResult<NcScale> {
@@ -496,7 +479,7 @@ impl Nc {
 
     /// Refreshes the physical screen to match what was last rendered (i.e.,
     /// without reflecting any changes since the last call to
-    /// [render][crate::Nc#method.render]).
+    /// [`render`][crate::Nc#method.render]).
     ///
     /// Returns the current screen geometry (`y`, `x`).
     ///
@@ -523,12 +506,13 @@ impl Nc {
     }
 
     /// Performs the rendering and rasterization portion of
-    /// [render][Nc#method.render] but do not write the resulting buffer
+    /// [`render`][Nc#method.render] but do not write the resulting buffer
     /// out to the terminal.
     ///
     /// Using this function, the user can control the writeout process,
     /// and render a second frame while writing another.
     ///
+    // possible BUG? CHECK:
     /// The returned buffer must be freed by the caller.
     ///
     /// *C style function: [notcurses_render_to_buffer()][crate::notcurses_render_to_buffer].*
@@ -549,7 +533,7 @@ impl Nc {
 
     /// Writes the last rendered frame, in its entirety, to 'fp'.
     ///
-    /// If [render()][Nc#method.render] has not yet been called,
+    /// If [`render`][Nc#method.render] has not yet been called,
     /// nothing will be written.
     ///
     /// *C style function: [notcurses_render_to_file()][crate::notcurses_render_to_file].*
@@ -613,7 +597,7 @@ impl Nc {
     //     crate::notcurses_stddim_yx_const(self, y, x)
     // }
 
-    /// Returns a mutable reference to the standard [NcPlane] for this terminal.
+    /// Returns a mutable reference to the standard [`NcPlane`] for this terminal.
     ///
     /// The standard plane always exists, and its origin is always at the
     /// uppermost, leftmost cell.
@@ -623,7 +607,7 @@ impl Nc {
         unsafe { &mut *crate::notcurses_stdplane(self) }
     }
 
-    /// Returns a reference to the standard [NcPlane] for this terminal.
+    /// Returns a reference to the standard [`NcPlane`] for this terminal.
     ///
     /// The standard plane always exists, and its origin is always at the
     /// uppermost, leftmost cell.
@@ -640,21 +624,21 @@ impl Nc {
         error![unsafe { crate::notcurses_stop(self) }]
     }
 
-    /// Gets the name of an [NcBlitter] blitter.
+    /// Gets the name of an [`NcBlitter`] blitter.
     ///
     /// *C style function: [notcurses_str_blitter()][crate::notcurses_str_blitter].*
     pub fn str_blitter(blitter: NcBlitter) -> String {
         rstring![crate::notcurses_str_blitter(blitter)].to_string()
     }
 
-    /// Gets the name of an [NcScale] scaling mode.
+    /// Gets the name of an [`NcScale`] scaling mode.
     ///
     /// *C style function: [notcurses_str_scalemode()][crate::notcurses_str_scalemode].*
     pub fn str_scalemode(scalemode: NcScale) -> String {
         rstring![crate::notcurses_str_scalemode(scalemode)].to_string()
     }
 
-    /// Returns an [NcStyle] with the supported curses-style attributes.
+    /// Returns an [`NcStyle`] with the supported curses-style attributes.
     ///
     /// The attribute is only indicated as supported if the terminal can support
     /// it together with color.
@@ -673,7 +657,7 @@ impl Nc {
         crate::notcurses_term_dim_yx(self)
     }
 
-    /// Returns the topmost [NcPlane], of which there is always at least one.
+    /// Returns the topmost [`NcPlane`], of which there is always at least one.
     ///
     /// *C style function: [notcurses_top()][crate::notcurses_top].*
     pub fn top(&mut self) -> &mut NcPlane {
