@@ -6,9 +6,9 @@ use core::{
 
 use crate::{
     cstring, error, error_ref, error_ref_mut, rstring, Nc, NcAlign, NcAlphaBits, NcBlitter,
-    NcBoxMask, NcCell, NcChannel, NcChannels, NcComponent, NcDim, NcEgc, NcError, NcFadeCb,
-    NcOffset, NcPaletteIndex, NcPixelGeometry, NcPlane, NcPlaneOptions, NcResizeCb, NcResult,
-    NcRgb, NcStyle, NcTime, NCRESULT_ERR,
+    NcBoxMask, NcCell, NcChannel, NcChannels, NcComponent, NcDim, NcError, NcFadeCb, NcOffset,
+    NcPaletteIndex, NcPixelGeometry, NcPlane, NcPlaneOptions, NcResizeCb, NcResult, NcRgb, NcStyle,
+    NcTime, NCRESULT_ERR,
 };
 
 /// # NcPlaneOptions Constructors
@@ -206,6 +206,13 @@ impl NcPlane {
         crate::ncplane_channels(self)
     }
 
+    /// Sets the current [`NcChannels`] for this `NcPlane`.
+    ///
+    /// *C style function: [ncplane_set_channels()][crate::ncplane_set_channels].*
+    pub fn set_channels(&mut self, channels: NcChannels) {
+        crate::ncplane_set_channels(self, channels);
+    }
+
     /// Gets the foreground [`NcChannel`] from an [NcPlane].
     ///
     /// *C style function: [ncplane_fchannel()][crate::ncplane_fchannel].*
@@ -222,13 +229,6 @@ impl NcPlane {
         crate::ncchannels_bchannel(crate::ncplane_channels(self))
     }
 
-    /// Sets the current [`NcChannels`] for this `NcPlane`.
-    ///
-    /// *C style function: [ncplane_set_channels()][crate::ncplane_set_channels].*
-    pub fn set_channels(&mut self, channels: NcChannels) {
-        crate::ncplane_set_channels(self, channels);
-    }
-
     /// Sets the current foreground [`NcChannel`] for this `NcPlane`.
     /// Returns the updated [`NcChannels`].
     ///
@@ -530,19 +530,19 @@ impl NcPlane {
 }
 
 // -----------------------------------------------------------------------------
-/// ## NcPlane methods: `NcCell` & `NcEgc`
+/// ## NcPlane methods: `NcCell` & strings
 impl NcPlane {
     /// Retrieves the current contents of the [`NcCell`] under the cursor,
-    /// returning the [`NcEgc`] and writing out the [`NcStyle`] and the [`NcChannels`].
+    /// returning the `EGC` and writing out the [`NcStyle`] and the [`NcChannels`].
     ///
-    /// This NcEgc must be freed by the caller.
+    /// This `EGC` must be freed by the caller.
     ///
     /// *C style function: [ncplane_at_cursor()][crate::ncplane_at_cursor].*
     pub fn at_cursor(
         &mut self,
         stylemask: &mut NcStyle,
         channels: &mut NcChannels,
-    ) -> NcResult<NcEgc> {
+    ) -> NcResult<String> {
         let egc = unsafe { crate::ncplane_at_cursor(self, stylemask, channels) };
         if egc.is_null() {
             return Err(NcError::with_msg(
@@ -550,12 +550,11 @@ impl NcPlane {
                 &format!("NcPlane.at_cursor({:0X}, {:0X})", stylemask, channels),
             ));
         }
-        let egc = core::char::from_u32(unsafe { *egc } as u32).expect("wrong char");
-        Ok(egc)
+        Ok(rstring![egc].into())
     }
 
     /// Retrieves the current contents of the [`NcCell`] under the cursor
-    /// into `cell`. Returns the number of bytes in the [`NcEgc`].
+    /// into `cell`. Returns the number of bytes in the `EGC`.
     ///
     /// This NcCell is invalidated if the associated NcPlane is destroyed.
     ///
@@ -571,9 +570,9 @@ impl NcPlane {
     }
 
     /// Retrieves the current contents of the specified [`NcCell`], returning the
-    /// [`NcEgc`] and writing out the [`NcStyle`] and the [`NcChannels`].
+    /// `EGC` and writing out the [`NcStyle`] and the [`NcChannels`].
     ///
-    /// This NcEgc must be freed by the caller.
+    /// This `EGC` must be freed by the caller.
     ///
     /// *C style function: [ncplane_at_yx()][crate::ncplane_at_yx].*
     pub fn at_yx(
@@ -582,7 +581,7 @@ impl NcPlane {
         x: NcDim,
         stylemask: &mut NcStyle,
         channels: &mut NcChannels,
-    ) -> NcResult<NcEgc> {
+    ) -> NcResult<String> {
         let egc = unsafe { crate::ncplane_at_yx(self, y as i32, x as i32, stylemask, channels) };
         if egc.is_null() {
             return Err(NcError::with_msg(
@@ -593,12 +592,11 @@ impl NcPlane {
                 ),
             ));
         }
-        let egc = core::char::from_u32(unsafe { *egc } as u32).expect("wrong char");
-        Ok(egc)
+        Ok(rstring![egc].into())
     }
 
     /// Retrieves the current contents of the specified [`NcCell`] into `cell`.
-    /// Returns the number of bytes in the [`NcEgc`].
+    /// Returns the number of bytes in the `EGC`.
     ///
     /// This NcCell is invalidated if the associated plane is destroyed.
     ///
@@ -674,7 +672,7 @@ impl NcPlane {
         ]
     }
 
-    /// Creates a flat string from the `NcEgc`'s of the selected region of the
+    /// Creates a flat string from the `EGC`'s of the selected region of the
     /// `NcPlane`.
     ///
     /// Starts at the plane's `beg_y` * `beg_x` coordinates (which must lie on
@@ -767,14 +765,15 @@ impl NcPlane {
     }
 
     // TODO: call put_egc
-    // /// Replaces the [`NcEgc`][crate::NcEgc] to the current location, but retain
+    // /// Replaces the `EGC` to the current location, but retain
     // /// the styling. The current styling of the plane will not be changed.
     // pub fn putchar_stained(&mut self, y: NcDim, x: NcDim, ch: char) ->
     // NcResult<NcDim> {
     //     error![crate::ncplane_putchar_stained(self, ch)]
     // }
 
-    /// Replaces the [`NcEgc`][crate::NcEgc], but retain the styling.
+    /// Replaces the [NcCell] at the `y`,`x` coordinates with the provided
+    /// 7-bit `char`, but retain the styling.
     /// The current styling of the plane will not be changed.
     ///
     /// On success, returns the number of columns the cursor was advanced.
@@ -789,12 +788,10 @@ impl NcPlane {
         ]
     }
 
-    /// Writes a series of [`NcEgc`][crate::NcEgc]s to the current location,
-    /// using the current style.
+    /// Writes a string to the current location, using the current style.
     ///
-    /// Advances the cursor by some positive number of columns
-    /// (though not beyond the end of the plane),
-    /// and this number is returned on success.
+    /// Advances the cursor by some positive number of columns (though not
+    /// beyond the end of the plane), and this number is returned on success.
     ///
     /// On error, a non-positive number is returned, indicating
     /// the number of columns which were written before the error.
@@ -836,8 +833,7 @@ impl NcPlane {
         ]
     }
 
-    /// Writes a series of [`NcEgc`][crate::NcEgc]s to the current location, but
-    /// retains the styling.
+    /// Writes a string to the current location, but retains the styling.
     ///
     /// The current styling of the plane will not be changed.
     ///
@@ -857,8 +853,7 @@ impl NcPlane {
         ]
     }
 
-    /// Write a string, which is a series of [`NcEgc`][crate::NcEgc]s, to the
-    /// current location, using the current style.
+    /// Writes a string to the provided location, using the current style.
     ///
     /// They will be interpreted as a series of columns.
     ///
@@ -919,7 +914,7 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_dup()][crate::ncplane_dup].*
     //
-    // TODO: deal with the opaque field.
+    // TODO: deal with the opaque field that is stored in NcPlaneOptions.userptr
     pub fn dup(&mut self) -> &mut NcPlane {
         unsafe { &mut *crate::ncplane_dup(self, null_mut()) }
     }
@@ -1665,6 +1660,11 @@ impl NcPlane {
         unsafe { crate::ncplane_y(self) as NcOffset }
     }
 
+    /// Returns `true` if this `NcPlane` has scrolling enabled, or `false` otherwise.
+    pub fn scrolling_p(&self) -> bool {
+        unsafe { crate::ncplane_scrolling_p(self) }
+    }
+
     /// Sets the scrolling behaviour of the plane, and
     /// returns true if scrolling was previously enabled, of false, if disabled.
     ///
@@ -1931,7 +1931,7 @@ impl NcPlane {
     /// *C style function: [ncplane_gradient()][crate::ncplane_gradient].*
     pub fn gradient(
         &mut self,
-        egc: &NcEgc,
+        egc: &str,
         stylemask: NcStyle,
         ul: NcChannels,
         ur: NcChannels,
@@ -1940,25 +1940,7 @@ impl NcPlane {
         y_stop: NcDim,
         x_stop: NcDim,
     ) -> NcResult<NcDim> {
-        // https://github.com/dankamongmen/notcurses/issues/1339
-        #[cfg(any(target_arch = "x86_64", target_arch = "i686"))]
-        let egc_ptr = &(*egc as i8);
-        #[cfg(not(any(target_arch = "x86_64", target_arch = "i686")))]
-        let egc_ptr = &(*egc as u8);
-
-        let res = unsafe {
-            crate::ncplane_gradient(
-                self,
-                egc_ptr,
-                stylemask as u32,
-                ul,
-                ur,
-                ll,
-                lr,
-                y_stop as i32,
-                x_stop as i32,
-            )
-        };
+        let res = crate::ncplane_gradient(self, egc, stylemask, ul, ur, ll, lr, y_stop, x_stop);
         error![res, "", res as NcDim]
     }
 
@@ -1971,12 +1953,12 @@ impl NcPlane {
     #[inline]
     pub fn gradient_sized(
         &mut self,
-        egc: &NcEgc,
+        egc: &str,
         stylemask: NcStyle,
-        ul: NcChannel,
-        ur: NcChannel,
-        ll: NcChannel,
-        lr: NcChannel,
+        ul: NcChannels,
+        ur: NcChannels,
+        ll: NcChannels,
+        lr: NcChannels,
         y_len: NcDim,
         x_len: NcDim,
     ) -> NcResult<NcDim> {
